==> yst-sale-api-1.1.1.210-20230621.081845-2-sources.jar: com/elitesland/sale/api/vo/resp/shop/MktDiscountOffsetVO.java <==
package com.elitesland.sale.api.vo.resp.shop;

import com.elitesland.sale.api.AmtBigDecimalJsonSerialize;
import com.elitesland.sale.api.PriceBigDecimalJsonSerialize;
import com.elitescloud.cloudt.common.annotation.SysCode;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;

/**
 * <p>
 * 满减折扣信息 VO
 * </p>
 *
 * @author ssy
 * @since 2021/8/24
 */
@ApiModel(description = "满减折扣信息")
@Data
public class MktDiscountOffsetVO implements Serializable {

    private static final long serialVersionUID = 5530829288304375973L;
    /**
     * 折扣主表
     */
    @ApiModelProperty(value = "折扣主表ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long mktDiscountOffsetId;

    @ApiModelProperty(value = "折扣编码")
    private String code;

    @ApiModelProperty(value = "折扣名称")
    private String name;

    @ApiModelProperty(value = "折扣生效时间")
    private LocalDateTime validStime;

    @ApiModelProperty(value = "折扣失效时间")
    private LocalDateTime validEtime;

    @ApiModelProperty(value = "客户等级")
    @SysCode(sys = "yst-sale", mod = "CUST_GROUP")
    private String customLevel;
    private String customLevelName;

    @ApiModelProperty(value = "销售公司ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long ouId;

    @ApiModelProperty(value = "销售公司编码")
    private String ouCode;

    @ApiModelProperty(value = "销售公司名称")
    private String ouName;

    @ApiModelProperty(value = "销售组织ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long buId;

    @ApiModelProperty(value = "销售组织编码")
    private String buCode;

    @ApiModelProperty(value = "销售组织名称")
    private String buName;

    @ApiModelProperty(value = "'促销条件:0 件数 1 金额")
    @SysCode(sys = "yst-sale", mod = "DISCOUNT_OFFSET_TYPE")
    private String type;
    private String TypeName;

    @ApiModelProperty(value = "促销状态")
    @SysCode(sys = "yst-sale", mod = "DISCOUNT_OFFSET_STATUS")
    private String status;
    private String statusName;

    /**
     * 折扣明细
     */
    @ApiModelProperty(value = "折扣明细表ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long mktDiscountOffsetDId;

    @ApiModelProperty(value = "商品ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long itemId;

    @ApiModelProperty(value = "商品编码")
    private String itemCode;

    @ApiModelProperty(value = "商品名称")
    private String itemName;

    @ApiModelProperty(value = "商品规格")
    private String itemAttr;

    @ApiModelProperty(value = "计量单位")
    private String uom;
    private String uomName;

    @ApiModelProperty(value = "满减达标金额")
    @JsonSerialize(using = AmtBigDecimalJsonSerialize.class)
    private BigDecimal limitAmt;

    @ApiModelProperty(value = "满减达标数量")
    private Long limitNum;

    @ApiModelProperty(value = "基础价格")
    @JsonSerialize(using = PriceBigDecimalJsonSerialize.class)
    private BigDecimal basePrice;

    @ApiModelProperty(value = "客户价格")
    @JsonSerialize(using = PriceBigDecimalJsonSerialize.class)
    private BigDecimal custPrice;

    @ApiModelProperty(value = "减免金额")
    @JsonSerialize(using = AmtBigDecimalJsonSerialize.class)
    private BigDecimal freeAmt;

    @ApiModelProperty(value = "折扣后价格")
    @JsonSerialize(using = PriceBigDecimalJsonSerialize.class)
    private BigDecimal discountPrice;

}

==> yst-sale-api-1.2.0.20-20230828.083246-1-sources.jar: com/elitesland/sale/api/vo/resp/shop/MktDiscountOffsetVO.java <==
package com.elitesland.sale.api.vo.resp.shop;

import com.elitesland.sale.api.AmtBigDecimalJsonSerialize;
import com.elitesland.sale.api.PriceBigDecimalJsonSerialize;
import com.elitescloud.cloudt.common.annotation.SysCode;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;

/**
 * <p>
 * 满减折扣信息 VO
 * </p>
 *
 * @author ssy
 * @since 2021/8/24
 */
@ApiModel(description = "满减折扣信息")
@Data
public class MktDiscountOffsetVO implements Serializable {

    private static final long serialVersionUID = 5530829288304375973L;
    /**
     * 折扣主表
     */
    @ApiModelProperty(value = "折扣主表ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long mktDiscountOffsetId;

    @ApiModelProperty(value = "折扣编码")
    private String code;

    @ApiModelProperty(value = "折扣名称")
    private String name;

    @ApiModelProperty(value = "折扣生效时间")
    private LocalDateTime validStime;

    @ApiModelProperty(value = "折扣失效时间")
    private LocalDateTime validEtime;

    @ApiModelProperty(value = "客户等级")
    @SysCode(sys = "yst-sale", mod = "CUST_LEVEL")
    private String customLevel;
    private String customLevelName;

    @ApiModelProperty(value = "销售公司ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long ouId;

    @ApiModelProperty(value = "销售公司编码")
    private String ouCode;

    @ApiModelProperty(value = "销售公司名称")
    private String ouName;

    @ApiModelProperty(value = "销售组织ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long buId;

    @ApiModelProperty(value = "销售组织编码")
    private String buCode;

    @ApiModelProperty(value = "销售组织名称")
    private String buName;

    @ApiModelProperty(value = "'促销条件:0 件数 1 金额")
    @SysCode(sys = "yst-sale", mod = "DISCOUNT_OFFSET_TYPE")
    private String type;
    private String TypeName;

    @ApiModelProperty(value = "促销状态")
    @SysCode(sys = "yst-sale", mod = "DISCOUNT_OFFSET_STATUS")
    private String status;
    private String statusName;

    /**
     * 折扣明细
     */
    @ApiModelProperty(value = "折扣明细表ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long mktDiscountOffsetDId;

    @ApiModelProperty(value = "商品ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long itemId;

    @ApiModelProperty(value = "商品编码")
    private String itemCode;

    @ApiModelProperty(value = "商品名称")
    private String itemName;

    @ApiModelProperty(value = "商品规格")
    private String itemAttr;

    @ApiModelProperty(value = "计量单位")
    private String uom;
    private String uomName;

    @ApiModelProperty(value = "满减达标金额")
    @JsonSerialize(using = AmtBigDecimalJsonSerialize.class)
    private BigDecimal limitAmt;

    @ApiModelProperty(value = "满减达标数量")
    private Long limitNum;

    @ApiModelProperty(value = "基础价格")
    @JsonSerialize(using = PriceBigDecimalJsonSerialize.class)
    private BigDecimal basePrice;

    @ApiModelProperty(value = "客户价格")
    @JsonSerialize(using = PriceBigDecimalJsonSerialize.class)
    private BigDecimal custPrice;

    @ApiModelProperty(value = "减免金额")
    @JsonSerialize(using = AmtBigDecimalJsonSerialize.class)
    private BigDecimal freeAmt;

    @ApiModelProperty(value = "折扣后价格")
    @JsonSerialize(using = PriceBigDecimalJsonSerialize.class)
    private BigDecimal discountPrice;

}
